@@ -27,19 +27,19 @@ sub gather_violations_generic {
 
     my %imported;
 
-    my $include_statements = $elem->find(sub { $_[1]->isa('PPI::Statement::Include') }) || [];
+    my $include_statements = $elem->find(sub { $_[1]->isa('PPI::Statement::Include') && !$_[1]->pragma }) || [];
     for my $st (@$include_statements) {
         next if $st->schild(0) eq 'no';
         my $expr_qw = $st->find( sub { $_[1]->isa('PPI::Token::QuoteLike::Words'); }) or next;
 
         my $included_module = $st->schild(1);
-        next if $included_module =~ /\A[a-z:]*\z/ || $is_special{$included_module};
+        next if $is_special{$included_module};
 
         if (@$expr_qw == 1) {
             my $expr = $expr_qw->[0];
             my @words = $expr_qw->[0]->literal;
             for my $w (@words) {
-                next if $w =~ /\A [:\-]/x;
+                next if $w =~ /\A [:\-\+]/x;
                 push @{ $imported{$w} //=[] }, $included_module;
             }
         }
@@ -57,7 +57,7 @@ sub gather_violations_generic {
     my @to_report = grep { !$used{$_} } (sort keys %imported);
     for my $tok (@to_report) {
         for my $inc_mod (@{ $imported{$tok} }) {
-            push @violations, $self->violation( 'Unused import', "A token <$tok> is imported but not used in the same code.", $inc_mod );
+            push @violations, $self->violation( "Unused import: $tok", "A token is imported but not used in the same code.", $inc_mod );
         }
     }
 
